Learn R Programming

gensphere (version 1.0)

genspheremisc: Miscellaneous functions used in working with generalized spherical laws

Description

Miscellaneous internal functions for the gensphere package.

Usage

gs.cone(x, mu, theta0) gs.elliptical(x, B) gs.gen.lp.norm(x, p, A) gs.lp.norm(x,p) gs.proj.normal(x, mu, sigma) gs.vfunc.eval(cfunc, x) gs.pdf2d.plot(gs.dist, xy.grid = seq(-10, 10, 0.1) ) RefineSphericalTessellation(V1, V2) NearbyPointsOnSphere(x, epsilon) RotateInNDimensions(x, y) "print"(x,...) "print"(x,...) "plot"(x,multiplier=1,...)

Arguments

x,y
vectors representing points in d-dimensional space
mu
direction of the mode for a cone/normal bump
theta0
angle between peak of the cone and the base of the cone
B
(d x d) positive definite shape matrix
A
matrix used to compute || A x ||_p
p
power of the l^p norm; p=2 is Euclidean distance
gs.dist
object of class "gensphere.distribution" defined by gensphere
xy.grid
a matrix of (x,y) values in 2-dimensions
cfunc
an object of class "gensphere.contour" defined by cfunc.new, etc.
...
optional arguments to the 2-dimensional plot, e.g. col='red', etc.
sigma
scale parameter for a normal bump
epsilon
vector of positive numbers where there are points added around a particular direction
V1,V2
matrices of vertices which are joined together to get a refinement of the grid
multiplier
a positive number used to scale the contour

Details

These are undocumented functions that are used internally. The functions gs.cone, gs.elliptical, gs.gen.lp.norm, gs.lp.norm, gs.proj.normal, gs.vfunc.eval are used in evalutating a contour function. RefineSphericalTessellation, NearbyPointsOnSphere are used in defining the tessellation of the contour that identifies bumps and cones. gs.pdf2d.plot and the plot/print methods are initial attempts at plotting and printing a summary of objects.

These functions may change or disappear in the future.