cfunc.new, cfunc.add.term, cfunc.finish give a flexible way to define a range of shapes for the
star-shaped contours. Then function gensphere defines a generalized spherical distribution
using a contour function and a specification of the radial term. Function dgensphere is used
to compute the multivariate density g(x) for X and function rgensphere is
used to simulate a sample random vectors with the (approximate) distribution X.A large class of distribution can be described as generalized spherical laws. In particular, all isotropic/radially symmetric distributions and all elliptically contoured distributions are generalized spherical laws. Such distributions can be represented as: $X = R S,$ where R is a positive random variable and S is a random vector distributed uniformly (with respect to surface area) on the contour, see Nolan (2015).
Throughout this package, points in d-dimensional space are represented as column vectors; this is different than what base R and packages mvmesh, geometry, etc. use; but it is the same as package SphericalCubature, SimplicialCubature, and other packages.
This research was supported by an agreement with Cornell University, Operations Research & Information Engineering, under contract W911NF-12-1-0385 from the Army Research Development and Engineering Command.
Please let me know if you find any mistakes. I will try to fix bugs promptly. Constructive comments for improvements are welcome; actually implementing any suggestions will be dependent on time constraints.
C. Fernandez, J. Osiewalksi and M. F. J. Steel, Modeling and Inference with v-Spherical Distributions, J. Amer. Stat. Assoc., 90, 1331-1340, 1995 J. P. Nolan, Models for generalized spherical and related distributions. arXiv preprint, Sept. 2015
cfunc.new, gensphere