gs.cone(x, mu, theta0)
gs.elliptical(x, B)
gs.gen.lp.norm(x, p, A)
gs.lp.norm(x,p)
gs.proj.normal(x, mu, sigma)
gs.vfunc.eval(cfunc, x)
gs.pdf2d.plot(gs.dist, xy.grid = seq(-10, 10, 0.1) )
RefineSphericalTessellation(V1, V2)
NearbyPointsOnSphere(x, epsilon)
RotateInNDimensions(x, y)
"print"(x,...)
"print"(x,...)
"plot"(x,multiplier=1,...)gensphere
cfunc.new, etc.
gs.cone, gs.elliptical, gs.gen.lp.norm, gs.lp.norm,
gs.proj.normal, gs.vfunc.eval are used in evalutating a contour function.
RefineSphericalTessellation, NearbyPointsOnSphere are used in defining
the tessellation of the contour that identifies bumps and cones.
gs.pdf2d.plot and the plot/print methods are initial attempts at plotting and
printing a summary of objects. These functions may change or disappear in the future.